"""
chrono24
~~~~~~~~
"""

# Import chrono24 and use chrono24.query to interface Chrono24
from chrono24.api import Chrono24 as query
from chrono24.filters import Filters as filters

__version__ = "0.3.2"
